%define python3_pkgversion 3.11
%global pypi_name pip-tools
%global pypi_version 7.4.1

Name:           python-%{pypi_name}
Version:        %{pypi_version}
Release:        1%{?dist}
Epoch:          1
Summary:        Tool to keep pinned dependencies up to date

Group:          Development/Languages
License:        BSD-3-Clause
URL:            https://github.com/jazzband/pip-tools/
Source:         https://files.pythonhosted.org/packages/source/p/pip-tools/pip-tools-%{version}.tar.gz
Patch0:         0001-add-setup-py.patch
BuildArch:      noarch

%description
pip-tools keeps pinned dependencies inside a project up to date.


%package -n python%{python3_pkgversion}-%{pypi_name}
Summary:        Tool to keep pinned dependencies up to date
%{?python_provide:%python_provide python%{python3_pkgversion}-%{pypi_name}}
BuildRequires:  %{?scl_prefix}python%{python3_pkgversion}-devel
BuildRequires:  %{?scl_prefix}python%{python3_pkgversion}-setuptools
BuildRequires:  %{?scl_prefix}python%{python3_pkgversion}-rpm-macros

# TESTS
BuildRequires:  python%{python3_pkgversion}-click
BuildRequires:  python%{python3_pkgversion}-pytest

%description -n python%{python3_pkgversion}-%{pypi_name}
pip-tools keeps pinned dependencies inside a project up to date.

%package doc
Summary: API documentation for python-%{pypi_name}
%description doc
This package contains %{summary}.

%prep
%autosetup -p1 -n %{pypi_name}-%{version}
# Remove bundled egg-info
rm -rf %{pypi_name}.egg-info

%build
%py3_build


%install
%py3_install


%files -n python%{python3_pkgversion}-%{pypi_name}
%license LICENSE
%doc README.md CHANGELOG.md
%{_bindir}/pip-sync
%{_bindir}/pip-compile
%{python3_sitelib}/piptools/
%{python3_sitelib}/pip_tools-%{version}-py%{python3_version}.egg-info


%files doc
%license LICENSE
%doc docs/index.md

%changelog
* Mon Aug 12 2024 Teo Gonzalez <teo.g.gonzalez@oracle.com> - 7.4.1
- Update to v7.4.1
- Uses template specfile
- Adds setup.py file to fix compat
- Removes existing tests because of tomli_w dependency

* Tue Mar 19 2024 Daniel Garcia <daniel.garcia@suse.com>
- Update to 7.4.1:
  * Skip constraint path check (#2038).
  * Fix collecting deps for all extras in multiple input packages (#1981).
- 7.4.0:
  * Features:
  - Allow force-enabling or force-disabling colorized output (#2041).
  - Add support for command-specific configuration sections (#1966).
  - Add options for including build dependencies in compiled output (#1681).
  * Bug Fixes:
  - Fix for src-files not being used when specified in a config file (#2015).
  - Fix ignorance of inverted CLI options in config for pip-sync (#1989).
  - Filter out origin ireqs for extra requirements before writing output annotations (#2011).
  - Make BacktrackingResolver ignore extras when dropping existing constraints (#1984).
  - Display pyproject.toml's metatada parsing errors in verbose mode (#1979).
  * Other Changes:
  - Add mention of pip-compile-multi in Other useful tools README section (#1986).
* Fri Nov 24 2023 Steve Kowalik <steven.kowalik@suse.com>
- Skip a recalcitrant test with the backtracking resolver
* Sun Aug 13 2023 Dirk Müller <dmueller@suse.com>
- update to 7.3.0:
  * Add `--no-strip-extras` and warn about strip extras by
    default
  * Fix revealed default config in header if requirements in
    subfolder
  * Direct references show extra requirements in .txt files
  * Document how to run under `pipx run`
  * Document that the backtracking resolver is the current
    default
  * Add `-c/--constraint` option to `pip-compile`
  * Allow options in config from both `pip-compile` and `pip-
    sync`
  * Fix rejection of negating CLI boolean flags in config
  * Validate parsed config against CLI options
  * Fix a bug where pip-sync would unexpectedly uninstall some
    packages
  * Backwards Incompatible Changes:
  * Default to `--resolver=backtracking`
  * Drop support for Python 3.7
  * Add support for `pip==23.2` where refactored out `DEV_PKGS`
  * Add `--no-config` option (#1896).
  * Sync direct references with hashes
  * Fix missing `via`s when more than two input files are used
  * Support config defaults using `.pip-tools.toml` or
    `pyproject.toml`
  * Log a warning if the user specifies `-P` and the output file
    is present but empty
  * Improve warning for `pip-compile` if no `--allow-unsafe` was
    passed
  * Correct in README `pre-commit` hook to run off
    `requirements.in`
  * Add pyprojects.toml example for using setuptools
* Thu Jun 22 2023 Markéta Machová <mmachova@suse.com>
- Update to 6.13.0
  * Add support for self-referential extras
  * Add support for pip 23.1
  * Pass --cache-dir to --pip-args for backtracking resolver
* Fri Feb 24 2023 Daniel Garcia <daniel.garcia@suse.com>
- Update to 6.12.2
  - Raise error if input and output filenames are matched (#1787).
    Thanks @atugushev
  - Add pyproject.toml as default input file format (#1780). Thanks
    @berislavlopac
  - Fix a regression with unsafe packages for --allow-unsafe (#1788).
    Thanks @q0w
- 6.12.1 (2022-12-16)
  - Set explicitly packages for setuptools (#1782). Thanks @q0w
- 6.12.0 (2022-12-13)
  - Add --no-index flag to pip-compile (#1745). Thanks @atugushev
  - Treat --upgrade-packages PKGSPECs as constraints (not just
    minimums), consistently (#1578). Thanks @AndydeCleyre
  - Filter out the user provided unsafe packages (#1766). Thanks @q0w
  - Adopt PEP-621 for packaging (#1763). Thanks @ssbarnea
- 6.11.0 (2022-11-30)
  - Add pyproject.toml file (#1643). Thanks @otherJL0
  - Support build isolation using setuptools/pyproject.toml
    requirement files (#1727). Thanks @atugushev
  - Improve punctuation/grammar with pip-compile header (#1547).
    Thanks @blueyed
  - Generate hashes for all available candidates (#1723). Thanks
    @neykov
  - Bump click minimum version to >= 8 (#1733). Thanks @atugushev
  - Bump pip minimum version to >= 22.2 (#1729). Thanks @atugushev
- 6.10.0 (2022-11-13)
  - Deprecate pip-compile --resolver=legacy (#1724). Thanks @atugushev
  - Prompt user to use the backtracking resolver on errors (#1719).
    Thanks @maxfenv
  - Add support for Python 3.11 final (#1708). Thanks @hugovk
  - Add --newline=[LF|CRLF|native|preserve] option to pip-compile
    (#1652). Thanks @AndydeCleyre
  - Fix inconsistent handling of constraints comments with
    backtracking resolver (#1713). Thanks @mkniewallner
  - Fix some encoding warnings in Python 3.10 (PEP 597) (#1614).
    Thanks @GalaxySnail
  - Update pip-tools version in the README's pre-commit examples
    (#1701). Thanks @Kludex
  - Document use of the backtracking resolver (#1718). Thanks @maxfenv
  - Use HTTPS in a readme link (#1716). Thanks @Arhell
- 6.9.0 (2022-10-05)
  - Add --all-extras flag to pip-compile (#1630). Thanks @apljungquist
  - Support Exclude Package with custom unsafe packages (#1509).
    Thanks @hmc-cs-mdrissi
  - Fix compile cached vcs packages (#1649). Thanks @atugushev
  - Include py.typed in wheel file (#1648). Thanks @FlorentJeannot
  - Add pyproject.toml & modern packaging to introduction. (#1668).
    Thanks @hynek
- 6.8.0 (2022-06-30)
  - Add support for pip's 2020 dependency resolver. Use pip-compile
  - -resolver backtracking to enable new resolver (#1539). Thanks
    @atugushev
- 6.7.0 (2022-06-27)
  - Support for the importlib.metadata metadata implementation
    (#1632). Thanks @richafrank
  - Instantiate a new accumulator InstallRequirement for
    combine_install_requirements output (#1519). Thanks @richafrank
  - Replace direct usage of the pep517 module with the build module,
    for loading project metadata (#1629). Thanks @AndydeCleyre
- 6.6.2 (2022-05-23)
  - Update PyPIRepository::resolve_reqs() for pip>=22.1.1 (#1624).
    Thanks @m000
* Thu Oct 20 2022 pgajdos@suse.com
- python-six is not required
* Thu Jun 16 2022 Steve Kowalik <steven.kowalik@suse.com>
- Update to 6.6.2:
  * Fix support for pip>=22.1 (#1618).
  * Update PyPIRepository::resolve_reqs() for pip>=22.1.1 (#1624).
- Add ca-certificates to BuildRequires.
* Thu Apr  7 2022 pgajdos@suse.com
- version update to 6.6.0
  Features:
  - Add support for pip>=22.1 ([#1607](https://github.com/jazzband/pip-tools/pull/1607)).
    Thanks @atugushev
  Bug Fixes:
  - Ensure `pip-compile --dry-run --quiet` still shows what would be done, while omitting
    the dry run message ([#1592](https://github.com/jazzband/pip-tools/pull/1592)). Thanks
    @AndydeCleyre
  - Fix `--generate-hashes` when hashes are computed from files
    ([#1540](https://github.com/jazzband/pip-tools/pull/1540)). Thanks @RazerM
- python-mock is not required for build
* Mon Feb 28 2022 pgajdos@suse.com
- version update to 6.5.1
  Backwards Incompatible Changes:
  - Remove support for EOL Python 3.5 and 2.7
    ([#1243](https://github.com/jazzband/pip-tools/pull/1243)). Thanks @jdufresne
  - Remove deprecated `--index/--no-index` option from `pip-compile`
    ([#1234](https://github.com/jazzband/pip-tools/pull/1234)). Thanks @jdufresne
  See CHANGELOG.md for more
* Wed Nov 25 2020 John Vandenberg <jayvdb@gmail.com>
- Update for v5.4.0
* Sat Sep 19 2020 John Vandenberg <jayvdb@gmail.com>
- Recreate package for v5.3.1
* Fri Oct 18 2019 Marketa Calabkova <mcalabkova@suse.com>
- Update to 4.2.0
  * Add --ask option to pip-sync
  * Add compatibility with pip>=19.3
* Fri Sep 13 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase.
* Tue Sep 10 2019 John Vandenberg <jayvdb@gmail.com>
- Update to v4.1.0
* Wed Mar 13 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v3.5.0
